# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-10-26 08:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='MaintenanceMode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('maintenance', models.BooleanField(default=False)),
                ('maintenance_from', models.DateTimeField(blank=True, null=True)),
                ('maintenance_until', models.DateTimeField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Maintenance Mode',
            },
        ),
    ]
